@@ -3,7 +3,7 @@
 // Purpose:     Cairo canvas text
 // Author:      Alex Thuering
 // Created:     2011/06/23
-// RCS-ID:      $Id: SVGCanvasTextCairo.h,v 1.4 2011/07/22 21:53:02 ntalex Exp $
+// RCS-ID:      $Id: SVGCanvasTextCairo.h,v 1.5 2011/08/04 19:56:05 ntalex Exp $
 // Copyright:   (c) 2011 Alex Thuering
 // Licence:     wxWindows licence
 //////////////////////////////////////////////////////////////////////////////
@@ -12,8 +12,6 @@
 #define WX_SVG_CANVAS_TEXT_CAIRO_H
 
 #include "SVGCanvasItem.h"
-#include <cairo/cairo.h>
-#include <pango/pangocairo.h>
 
 class wxSVGCanvasTextCairo: public wxSVGCanvasText {
 public:
@@ -22,7 +20,6 @@ public:
 
 public:
 	virtual void InitText(const wxString& text, const wxCSSStyleDeclaration& style);
-	static PangoFontDescription* GetFontDescription(const wxCSSStyleDeclaration& style);
 };
 
 #endif // WX_SVG_CANVAS_TEXT_CAIRO_H
